@@ -1,7 +1,11 @@
 from argparse import ArgumentDefaultsHelpFormatter, ArgumentParser
+import importlib.metadata
 
 from .test import SpeedTestGroup
 
+__pkg__ = "fastcom-cli"
+__version__ = importlib.metadata.version(__pkg__)
+
 
 def main():
     parser = ArgumentParser(
@@ -32,7 +36,7 @@ def main():
         help="Outputs a JSON formatted summary (implies --quiet)",
     )
     parser.add_argument(
-        "-t",
+        "-r",
         "--trim",
         type=int,
         default=10,
@@ -41,6 +45,19 @@ def main():
             ' of the results for the "Mean (trimmed)" value'
         ),
     )
+    parser.add_argument(
+        "-t",
+        "--timeout",
+        type=int,
+        default=60,
+        help="Controls the number of seconds to wait before stopping all tests",
+    )
+    parser.add_argument(
+        "-v",
+        "--version",
+        action="version",
+        version=f"{__pkg__} {__version__}",
+    )
     args = parser.parse_args()
 
     if args.json:
@@ -49,7 +66,9 @@ def main():
     group = SpeedTestGroup(
         servers=args.servers, iterations=args.iterations, trim=args.trim
     )
-    group.run(verbose=not args.quiet, json_output=args.json)
+    group.run(
+        verbose=not args.quiet, json_output=args.json, timeout=args.timeout
+    )
 
 
 if __name__ == "__main__":
